==> scanbot_sdk-2.9.0.tar.gz: ios/Classes/Extensions/SDK/Cropping/SBSDKUICroppingScreenUIConfiguration.swift <==
//
//  SBSDKUICroppingScreenUIConfiguration.swift
//  scanbot_sdk
//
//  Created by Zhenya Knizhnik on 28.08.19.
//

import Foundation
import ScanbotSDK

extension SBSDKUICroppingScreenUIConfiguration {
    convenience init(from dictionary: [String: Any]) {
        self.init()
        if let hex = dictionary["topBarButtonsColor"] as? String {
            self.topBarButtonsColor = UIColor(hexString: hex)
        }
        
        if let hex = dictionary["topBarBackgroundColor"] as? String {
            self.topBarBackgroundColor = UIColor(hexString: hex)
        }
        
        if let hex = dictionary["titleColor"] as? String {
            self.titleColor = UIColor(hexString: hex)
        }
        
        if let hex = dictionary["bottomBarButtonsColor"] as? String {
            self.bottomBarButtonsColor = UIColor(hexString: hex)
        }
        
        if let hex = dictionary["bottomBarBackgroundColor"] as? String {
            self.bottomBarBackgroundColor = UIColor(hexString: hex)
        }
        
        if let hex = dictionary["polygonColor"] as? String {
            self.polygonColor = UIColor(hexString: hex)
        }
        
        if let hex = dictionary["polygonColorMagnetic"] as? String {
            self.polygonColorMagnetic = UIColor(hexString: hex)
        }
        
        if let hex = dictionary["backgroundColor"] as? String {
            self.backgroundColor = UIColor(hexString: hex)
        }
        
        if let rotateButtonHidden = dictionary["rotateButtonHidden"] as? Bool {
            self.isRotateButtonHidden = rotateButtonHidden
        }
        
        if let detectResetButtonHidden = dictionary["detectResetButtonHidden"] as? Bool {
            self.isDetectResetButtonHidden = detectResetButtonHidden
        }
        
        if let string = dictionary["orientationLockMode"] as? String {
            let allowedInterfaceOrientations = UIInterfaceOrientationMask(from: string)
            self.allowedInterfaceOrientations = allowedInterfaceOrientations
        }
    }
}

==> scanbot_sdk-2.10.0.tar.gz: ios/Classes/Extensions/SDK/Cropping/SBSDKUICroppingScreenUIConfiguration.swift <==
//
//  SBSDKUICroppingScreenUIConfiguration.swift
//  scanbot_sdk
//
//  Created by Zhenya Knizhnik on 28.08.19.
//

import Foundation
import ScanbotSDK

extension SBSDKUICroppingScreenUIConfiguration {
    convenience init(from dictionary: [String: Any]) {
        self.init()
        if let hex = dictionary["topBarButtonsColor"] as? String {
            self.topBarButtonsColor = UIColor(hexString: hex)
        }
        
        if let hex = dictionary["topBarBackgroundColor"] as? String {
            self.topBarBackgroundColor = UIColor(hexString: hex)
        }
        
        if let hex = dictionary["titleColor"] as? String {
            self.titleColor = UIColor(hexString: hex)
        }
        
        if let hex = dictionary["bottomBarButtonsColor"] as? String {
            self.bottomBarButtonsColor = UIColor(hexString: hex)
        }
        
        if let hex = dictionary["bottomBarBackgroundColor"] as? String {
            self.bottomBarBackgroundColor = UIColor(hexString: hex)
        }
        
        if let hex = dictionary["polygonColor"] as? String {
            self.polygonColor = UIColor(hexString: hex)
        }
        
        if let hex = dictionary["polygonColorMagnetic"] as? String {
            self.polygonColorMagnetic = UIColor(hexString: hex)
        }
        
        if let hex = dictionary["backgroundColor"] as? String {
            self.backgroundColor = UIColor(hexString: hex)
        }
        
        if let rotateButtonHidden = dictionary["rotateButtonHidden"] as? Bool {
            self.isRotateButtonHidden = rotateButtonHidden
        }
        
        if let detectResetButtonHidden = dictionary["detectResetButtonHidden"] as? Bool {
            self.isDetectResetButtonHidden = detectResetButtonHidden
        }
        
        if let string = dictionary["orientationLockMode"] as? String {
            let orientationLockMode = SBSDKOrientationLock(from: string)
            self.orientationLockMode = orientationLockMode
        }
    }
}
